@@ -25,10 +25,22 @@ class Table:
     header: List["HeaderColumn"]
     rows: List["Row"]
 
+    def to_csv(self) -> str:
+        header = ','.join([x.column_name for x in self.header])
+        rows = '\n'.join([str(row) for row in self.rows])
+        return f'{header}\n{rows}'
+
 
 @dataclass
 class Row:
-    pass
+    def __str__(self):
+        variables = []
+        for x in vars(self).values():
+            if isinstance(x, (int, float)):
+                variables.append(x)
+            else:
+                variables.append(f"'{x}'")
+        return ','.join([str(x).replace('\n', ' ') for x in variables])
 
 
 @dataclass
